@@ -96,25 +96,25 @@ function form_save() {
 					'color_id' => '0',
 					'graph_type_id' => '9',
 					'consolidation_function_id' => '4',
-					'text_format' => __('Current:'),
+					'text_format' => __('Cur:'),
 					'hard_return' => ''
 					),
 				1 => array(
 					'color_id' => '0',
 					'graph_type_id' => '9',
 					'consolidation_function_id' => '1',
-					'text_format' => __('Average:'),
+					'text_format' => __('Avg:'),
 					'hard_return' => ''
 					),
 				2 => array(
 					'color_id' => '0',
 					'graph_type_id' => '9',
 					'consolidation_function_id' => '3',
-					'text_format' => __('Maximum:'),
+					'text_format' => __('Max:'),
 					'hard_return' => 'on'
 					)
 			);
-		}elseif ($graph_item_types[get_nfilter_request_var('graph_type_id')] == 'LEGEND_CAMM') {
+		} elseif ($graph_item_types[get_nfilter_request_var('graph_type_id')] == 'LEGEND_CAMM') {
 	         /* this can be a major time saver when creating lots of graphs with the typical
 				GPRINT LAST/AVERAGE/MAX legends */
 			$items = array(
@@ -122,28 +122,28 @@ function form_save() {
 					'color_id' => '0',
 					'graph_type_id' => '9',
 					'consolidation_function_id' => '4',
-					'text_format' => __('Current:'),
+					'text_format' => __('Cur:'),
 					'hard_return' => ''
 				),
 				1 => array(
 					'color_id' => '0',
 					'graph_type_id' => '9',
 					'consolidation_function_id' => '1',
-					'text_format' => __('Average:'),
+					'text_format' => __('Avg:'),
 					'hard_return' => ''
 				),
 				2 => array(
 					'color_id' => '0',
 					'graph_type_id' => '9',
 					'consolidation_function_id' => '2',
-					'text_format' => __('Minimum:'),
+					'text_format' => __('Min:'),
 					'hard_return' => ''
 				),
 				3 => array(
 					'color_id' => '0',
 					'graph_type_id' => '9',
 					'consolidation_function_id' => '3',
-					'text_format' => __('Maximum:'),
+					'text_format' => __('Max:'),
 					'hard_return' => 'on'
 				)
 			);
@@ -206,7 +206,7 @@ function form_save() {
 			if (!is_error_message()) {
 				/* Before we save the item, let's get a look at task_item_id <-> input associations */
 				$orig_data_source_graph_inputs = db_fetch_assoc_prepared("SELECT
-					gtin.id, gtin.name, gti.task_item_id 
+					gtin.id, gtin.name, gti.task_item_id
 					FROM graph_template_input AS gtin
 					INNER JOIN graph_template_input_defs AS gtid
 					ON gtin.id = gtid.graph_template_input_id
@@ -227,44 +227,44 @@ function form_save() {
 						/* old item clean-up.  Don't delete anything if the item <-> task_item_id association remains the same. */
 						if (get_nfilter_request_var('_task_item_id') != get_nfilter_request_var('task_item_id')) {
 							/* It changed.  Delete any old associations */
-							db_execute_prepared('DELETE FROM graph_template_input_defs 
-								WHERE graph_template_item_id = ?', 
+							db_execute_prepared('DELETE FROM graph_template_input_defs
+								WHERE graph_template_item_id = ?',
 								array($graph_template_item_id));
 
 							/* Input for current data source exists and has changed.  Update the association */
 							if (isset($orig_data_source_to_input{$save['task_item_id']})) {
-								db_execute_prepared('REPLACE INTO graph_template_input_defs 
-									(graph_template_input_id, graph_template_item_id) 
-									VALUES (?, ?)', 
+								db_execute_prepared('REPLACE INTO graph_template_input_defs
+									(graph_template_input_id, graph_template_item_id)
+									VALUES (?, ?)',
 									array($orig_data_source_to_input{$save['task_item_id']}, $graph_template_item_id));
 							}
 						}
 
 						/* an input for the current data source does NOT currently exist, let's create one */
 						if (!isset($orig_data_source_to_input[$save['task_item_id']])) {
-							$ds_name = db_fetch_cell_prepared('SELECT data_source_name 
-								FROM data_template_rrd 
-								WHERE id = ?', 
+							$ds_name = db_fetch_cell_prepared('SELECT data_source_name
+								FROM data_template_rrd
+								WHERE id = ?',
 								array(get_nfilter_request_var('task_item_id')));
 
-							db_execute_prepared("REPLACE INTO graph_template_input 
-								(hash, graph_template_id, name, column_name) 
-								VALUES (?, ?, ?, 'task_item_id')", 
+							db_execute_prepared("REPLACE INTO graph_template_input
+								(hash, graph_template_id, name, column_name)
+								VALUES (?, ?, ?, 'task_item_id')",
 								array(get_hash_graph_template(0, 'graph_template_input'), $save['graph_template_id'], "Data Source [$ds_name]"));
 
 							$graph_template_input_id = db_fetch_insert_id();
 
-							$graph_items = db_fetch_assoc_prepared('SELECT id 
-								FROM graph_templates_item 
-								WHERE graph_template_id = ? 
-								AND task_item_id = ?', 
+							$graph_items = db_fetch_assoc_prepared('SELECT id
+								FROM graph_templates_item
+								WHERE graph_template_id = ?
+								AND task_item_id = ?',
 								array($save['graph_template_id'], get_nfilter_request_var('task_item_id')));
 
 							if (sizeof($graph_items)) {
 								foreach ($graph_items as $graph_item) {
-									db_execute_prepared('REPLACE INTO graph_template_input_defs 
-										(graph_template_input_id, graph_template_item_id) 
-										VALUES (?, ?)', 
+									db_execute_prepared('REPLACE INTO graph_template_input_defs
+										(graph_template_input_id, graph_template_item_id)
+										VALUES (?, ?)',
 										array($graph_template_input_id, $graph_item['id']));
 								}
 							}
@@ -277,7 +277,7 @@ function form_save() {
 						/* make sure all current graphs using this graph input are aware of this change */
 						push_out_graph_input($orig_data_source_to_input{get_nfilter_request_var('task_item_id')}, $graph_template_item_id, array($graph_template_item_id => $graph_template_item_id));
 					}
-				}else{
+				} else {
 					raise_message(2);
 				}
 			}
@@ -288,7 +288,7 @@ function form_save() {
 		if (is_error_message()) {
 			header('Location: graph_templates_items.php?header=false&action=item_edit&graph_template_item_id=' . (empty($graph_template_item_id) ? get_nfilter_request_var('graph_template_item_id') : $graph_template_item_id) . '&id=' . get_nfilter_request_var('graph_template_id'));
 			exit;
-		}else{
+		} else {
 			header('Location: graph_templates.php?header=false&action=template_edit&id=' . get_nfilter_request_var('graph_template_id'));
 			exit;
 		}
@@ -312,7 +312,7 @@ function item_movedown() {
 
 	if ((!empty($next_id)) && (isset($arr{get_request_var('id')}))) {
 		move_graph_group(get_request_var('id'), $arr, $next_id, 'next');
-	}elseif (preg_match('/(GPRINT|VRULE|HRULE|COMMENT)/', $graph_item_types{db_fetch_cell_prepared('SELECT graph_type_id FROM graph_templates_item WHERE id = ?', array(get_request_var('id')))})) {
+	} elseif (preg_match('/(GPRINT|VRULE|HRULE|COMMENT)/', $graph_item_types{db_fetch_cell_prepared('SELECT graph_type_id FROM graph_templates_item WHERE id = ?', array(get_request_var('id')))})) {
 		/* this is so we know the "other" graph item to propagate the changes to */
 		$next_item = get_item('graph_templates_item', 'sequence', get_request_var('id'), 'graph_template_id=' . get_request_var('graph_template_id') . ' AND local_graph_id=0', 'next');
 
@@ -337,7 +337,7 @@ function item_moveup() {
 
 	if ((!empty($next_id)) && (isset($arr{get_request_var('id')}))) {
 		move_graph_group(get_request_var('id'), $arr, $next_id, 'previous');
-	}elseif (preg_match('/(GPRINT|VRULE|HRULE|COMMENT)/', $graph_item_types{db_fetch_cell_prepared('SELECT graph_type_id FROM graph_templates_item WHERE id = ?', array(get_request_var('id')))})) {
+	} elseif (preg_match('/(GPRINT|VRULE|HRULE|COMMENT)/', $graph_item_types{db_fetch_cell_prepared('SELECT graph_type_id FROM graph_templates_item WHERE id = ?', array(get_request_var('id')))})) {
 		/* this is so we know the "other" graph item to propagate the changes to */
 		$last_item = get_item('graph_templates_item', 'sequence', get_request_var('id'), 'graph_template_id=' . get_request_var('graph_template_id') . ' AND local_graph_id=0', 'previous');
 
@@ -390,27 +390,27 @@ function item_edit() {
 
 	$header_label = __('Graph Template Items [edit graph: %s]', htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM graph_templates WHERE id = ?', array(get_request_var('graph_template_id')))));
 
-	html_start_box($header_label, '100%', '', '3', 'center', '');
+	html_start_box($header_label, '100%', true, '3', 'center', '');
 
 	if (!isempty_request_var('id')) {
-		$template_item = db_fetch_row_prepared('SELECT * 
-			FROM graph_templates_item 
-			WHERE id = ?', 
+		$template_item = db_fetch_row_prepared('SELECT *
+			FROM graph_templates_item
+			WHERE id = ?',
 			array(get_request_var('id')));
 	}
 
 	/* by default, select the LAST DS chosen to make everyone's lives easier */
 	if (!isempty_request_var('graph_template_id')) {
-		$default = db_fetch_row_prepared('SELECT task_item_id 
-			FROM graph_templates_item 
-			WHERE graph_template_id = ? 
-			AND local_graph_id = 0 
-			ORDER BY sequence DESC', 
+		$default = db_fetch_row_prepared('SELECT task_item_id
+			FROM graph_templates_item
+			WHERE graph_template_id = ?
+			AND local_graph_id = 0
+			ORDER BY sequence DESC',
 			array(get_request_var('graph_template_id')));
 
 		if (sizeof($default) > 0) {
 			$struct_graph_item['task_item_id']['default'] = $default['task_item_id'];
-		}else{
+		} else {
 			$struct_graph_item['task_item_id']['default'] = 0;
 		}
 	}
@@ -428,7 +428,7 @@ function item_edit() {
 
 	$form_array = array();
 
-	while (list($field_name, $field_array) = each($struct_graph_item)) {
+	foreach ($struct_graph_item as $field_name => $field_array) {
 		$form_array += array($field_name => $struct_graph_item[$field_name]);
 
 		$form_array[$field_name]['value'] = (isset($template_item) ? $template_item[$field_name] : '');
@@ -449,7 +449,7 @@ function item_edit() {
 
 		if (sizeof($graph_item_input_fields) > 0) {
 			foreach ($graph_item_input_fields as $field) {
-				$form_array{$field['column_name']}['friendly_name'] .= " [<a href='" . htmlspecialchars('graph_templates_inputs.php?action=input_edit&id=' . $field['id'] . '&graph_template_id=' . get_request_var('graph_template_id')) . "'>Field Not Templated</a>]";
+				$form_array{$field['column_name']}['friendly_name'] .= " [<a href='" . htmlspecialchars('graph_templates_inputs.php?action=input_edit&id=' . $field['id'] . '&graph_template_id=' . get_request_var('graph_template_id')) . "'>" . __('Field Not Templated') . "</a>]";
 			}
 		}
 	}
@@ -461,7 +461,7 @@ function item_edit() {
 		)
 	);
 
-	html_end_box();
+	html_end_box(true, true);
 
 	form_hidden_box('graph_template_item_id', (isset($template_item) ? $template_item['id'] : '0'), '');
 	form_hidden_box('graph_template_id', get_request_var('graph_template_id'), '0');
@@ -480,7 +480,7 @@ function item_edit() {
 		$('#shift').click(function(data) {
 			if ($('#shift').is(':checked')) {
 				$('#row_value').show();
-			}else{
+			} else {
 				$('#row_value').hide();
 			}
 		});
@@ -491,7 +491,7 @@ function item_edit() {
 		});
 	});
 
-	/* 
+	/*
 	columns - task_item_id color_id alpha graph_type_id consolidation_function_id cdef_id value gprint_id text_format hard_return
 
 	graph_type_ids - 1 - Comment 2 - HRule 3 - Vrule 4 - Line1 5 - Line2 6 - Line3 7 - Area 8 - Stack 9 - Gprint 10 - Legend
@@ -651,10 +651,10 @@ function item_edit() {
 			$('#row_textalign').hide();
 			$('#row_shift').hide();
 			$('#row_alpha').show();
-			$('#row_consolidation_function_id').show();
+			$('#row_consolidation_function_id').hide();
 			$('#row_cdef_id').show();
 			$('#row_vdef_id').show();
-			$('#row_value').hide();
+			$('#row_value').show();
 			$('#row_gprint_id').hide();
 			$('#row_text_format').show();
 			$('#row_hard_return').show();
